@@ -18,10 +18,14 @@ import decimal
 from gnocchiclient import client as gclient
 from keystoneauth1 import loading as ks_loading
 from oslo_config import cfg
+from oslo_utils import units
 
 from cloudkitty import collector
 
 GNOCCHI_COLLECTOR_OPTS = 'gnocchi_collector'
+gnocchi_collector_opts = ks_loading.get_auth_common_conf_options()
+
+cfg.CONF.register_opts(gnocchi_collector_opts, GNOCCHI_COLLECTOR_OPTS)
 ks_loading.register_session_conf_options(
     cfg.CONF,
     GNOCCHI_COLLECTOR_OPTS)
@@ -90,6 +94,18 @@ class GnocchiCollector(collector.BaseCollector):
             '1',
             session=self.session)
 
+    @classmethod
+    def get_metadata(cls, resource_name, transformers):
+        info = super(GnocchiCollector, cls).get_metadata(resource_name,
+                                                         transformers)
+        try:
+            info["metadata"].extend(transformers['GnocchiTransformer']
+                                    .get_metadata(resource_name))
+            info["unit"] = cls.units_mappings[resource_name][1]
+        except KeyError:
+            pass
+        return info
+
     @classmethod
     def gen_filter(cls, cop='=', lop='and', **kwargs):
         """Generate gnocchi filter from kwargs.
@@ -277,8 +293,13 @@ class GnocchiCollector(collector.BaseCollector):
                 start,
                 end)
             resource_data.pop('metrics', None)
-            if resource_data.get('type') == 'instance_network_interface':
-                resource_data[qty] = resource_data[qty] / 1000000.0
+            # Convert network.bw.in, network.bw.out and image unit to MB
+            if resource.get('type') == 'instance_network_interface':
+                resource_data[qty] = (
+                    decimal.Decimal(resource_data[qty]) / units.M)
+            elif resource.get('type') == 'image':
+                resource_data[qty] = (
+                    decimal.Decimal(resource_data[qty]) / units.Mi)
             data = self.t_cloudkitty.format_item(
                 resource_data,
                 unit,
